@@ -4,16 +4,24 @@ test_that("age groups can be created and manipulated", {
   ages <- seq_len(50)
   age_limits <- c(0, 5, 10)
   groups <- reduce_agegroups(ages, age_limits)
-  expect_length(unique(groups), 3)
-  age_groups <- limits_to_agegroups(groups)
-  expect_length(unique(age_groups), 3)
+  expect_identical(unique(groups), age_limits)
+  expect_warning(limits_to_agegroups(groups), "default")
+  age_groups <-
+  expect_identical(
+    as.character(unique(limits_to_agegroups(groups, notation = "brackets"))),
+    c("[0,5)", "[5,10)", "10+")
+  )
+  expect_identical(
+    as.character(unique(limits_to_agegroups(groups, notation = "dashes"))),
+    c("0-4", "5-9", "10+")
+  )
 })
 
 test_that("age groups are ordered factors", {
   ages <- seq_len(50)
   age_limits <- c(0, 5, 10)
   groups <- reduce_agegroups(ages, age_limits)
-  age_groups <- limits_to_agegroups(groups)
+  age_groups <- limits_to_agegroups(groups, notation = "dashes")
   expect_s3_class(age_groups, "ordered")
   expect_s3_class(age_groups, "factor")
 })
