@@ -12,7 +12,7 @@ polymod10 <- get_survey(polymod)
 polymod11 <- get_survey(polymod)
 
 polymod2$participants$added_weight <- 0.5
-polymod2$contacts$cnt_age <- factor(polymod2$contacts$cnt_age)
+polymod2$contacts$cnt_age_exact <- factor(polymod2$contacts$cnt_age_exact)
 polymod2$participants$part_age[1] <- "3-5"
 polymod3$participants$dayofweek <- NULL
 polymod3$participants$year <- NULL
@@ -25,16 +25,15 @@ polymod7$participants$country <- NULL
 polymod8$contacts$cnt_age_exact <- NA_real_
 polymod8$contacts$cnt_age_est_min <- NA_real_
 polymod8$contacts$cnt_age_est_max <- NA_real_
-polymod8$contacts$cnt_age <- NA_real_
-polymod8$contacts[polymod$contacts$part_id == 10, "cnt_age"] <- 10
-polymod8$contacts[polymod$contacts$part_id == 20, "cnt_age"] <- 20
+polymod8$contacts[polymod$contacts$part_id == 10, "cnt_age_exact"] <- 10
+polymod8$contacts[polymod$contacts$part_id == 20, "cnt_age_exact"] <- 20
 polymod9$participants$part_age_est_min <- 1
 polymod9$participants$part_age_est_max <- 15
-polymod9$participants$part_age <- NULL
+polymod9$participants$part_age_exact <- NULL
 polymod9$participants$part_age_est_min <- 1
 polymod9$participants$part_age_est_max <- 15
 nn <- nrow(polymod9$participants)
-polymod9$participants$part_age <- ifelse(runif(nn) > 0.7, 20, NA)
+polymod9$participants$part_age_exact <- ifelse(runif(nn) > 0.7, 20, NA)
 polymod10$participants$added_weight <-
   ifelse(polymod10$participants$hh_size > 1, 2, 1)
 polymod10$participants$added_weight2 <- 0.3
@@ -541,12 +540,3 @@ test_that("Contact matrices per capita are also generated when bootstrapping", {
     ), 2)
   })
 })
-
-test_that("passing a DOI for survey is deprecated", {
-  skip_if_offline("zenodo.org")
-  skip_on_cran()
-  skip_on_ci()
-  lifecycle::expect_deprecated(
-    contact_matrix(survey = "10.5281/zenodo.1095664") # nolint
-  )
-})
