@@ -31,7 +31,3 @@ test_that("missing surveys can't be cited", {
 test_that("multiple DOI's cannot be loaded", {
   expect_error(suppressMessages(suppressWarnings(get_survey(c("10.5281/zenodo.1095664", "10.5281/zenodo.1127693"))))) # nolint
 })
-
-test_that("deprecated functions are warned about", {
-  expect_warning(cite(polymod), "deprecated")
-})
